package com.huashe.park.core.mapper;

import com.huashe.park.domain.entity.ParkAttendUsrDetail;

import java.util.List;

/**
 * 用户打卡信息Mapper接口
 *
 * @author ruoyi
 * @date 2025-01-08
 */
public interface ParkAttendUsrDetailMapper {
    /**
     * 查询用户打卡信息
     *
     * @param id 用户打卡信息主键
     * @return 用户打卡信息
     */
    public ParkAttendUsrDetail selectParkAttendUsrDetailById(Long id);

    /**
     * 查询用户打卡信息列表
     *
     * @param parkAttendUsrDetail 用户打卡信息
     * @return 用户打卡信息集合
     */
    public List<ParkAttendUsrDetail> selectParkAttendUsrDetailList(ParkAttendUsrDetail parkAttendUsrDetail);

    /**
     * 新增用户打卡信息
     *
     * @param parkAttendUsrDetail 用户打卡信息
     * @return 结果
     */
    public int insertParkAttendUsrDetail(ParkAttendUsrDetail parkAttendUsrDetail);

    /**
     * 修改用户打卡信息
     *
     * @param parkAttendUsrDetail 用户打卡信息
     * @return 结果
     */
    public int updateParkAttendUsrDetail(ParkAttendUsrDetail parkAttendUsrDetail);

    /**
     * 删除用户打卡信息
     *
     * @param id 用户打卡信息主键
     * @return 结果
     */
    public int deleteParkAttendUsrDetailById(Long id);

    /**
     * 批量删除用户打卡信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteParkAttendUsrDetailByIds(Long[] ids);
}
